@@ -5,3 +5,6 @@
 
 pub mod error;
 pub mod secp256k1;
+
+#[cfg(test)]
+mod tests;
